import 'package:dashboard/graphing/usergraph.dart';
import 'package:dashboard/ui/graphs/community/index.dart';
import 'package:flutter/material.dart';
import '../data/post.dart';
import 'trustcolorcalculator.dart';

class PostNode extends StatelessWidget {
  final Post post;
  final Color trustColor;

  PostNode(this.post)
      : trustColor = TrustColorCalculator.calculateTrustColor(post.trust);

  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: () => redirectToPost(context),
      child: Row(
        children: [
          Expanded(
            child: Text(
              post.title != "" ? post.title : post.content,
              overflow: TextOverflow.ellipsis,
              style:
                  TextStyle(fontWeight: FontWeight.bold, color: Colors.black),
            ),
          ),
          Text(
            (post.trust * 100).roundToDouble().toString() + "%",
            style: TextStyle(fontWeight: FontWeight.bold, color: trustColor),
          ),
        ],
        mainAxisAlignment: MainAxisAlignment.spaceBetween,
      ),
    );
  }

  void redirectToPost(BuildContext context) {
    showDialog(
      context: context,
      builder: (_) => new PostNodeDialog(post, trustColor),
    );
  }
}

class PostNodeDialog extends StatelessWidget {
  PostNodeDialog(this.post, this.trustColor,
      {this.width = 350, this.height = 400});
  final Post post;

  final Color trustColor;
  final double titleSize = 22;
  final double width;
  final double height;

  Widget build(BuildContext context) {
    return AlertDialog(
      titlePadding: EdgeInsets.all(0),
      actions: [
        TextButton.icon(
          onPressed: () => redirectToCommunityGraph(context),
          icon: Icon(Icons.group_work),
          label: Text(post.community),
        ),
        SizedBox(width: 16),
        TextButton.icon(
          onPressed: () => redirectToUserGraph(context),
          icon: Icon(Icons.supervised_user_circle_rounded),
          label: Text(post.author),
        ),
      ],
      title: Container(
        width: width,
        decoration: BoxDecoration(
          color: Colors.blue,
          boxShadow: [BoxShadow(blurRadius: 0.2, spreadRadius: 0.2)],
        ),
        padding: EdgeInsets.all(5),
        child: Row(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: [
            Expanded(
              child: Text(
                post.title != "" ? post.title : "Comment",
                overflow: TextOverflow.ellipsis,
                style: TextStyle(
                  fontWeight: FontWeight.bold,
                  color: Colors.black,
                  fontSize: titleSize,
                ),
              ),
            ),
            IconButton(
              onPressed: () => Navigator.pop(context),
              icon: Icon(
                Icons.close,
                color: Colors.white,
              ),
            ),
          ],
        ),
      ),
      content: Container(
        width: width,
        height: height,
        child: Column(
          children: [
            Expanded(
              child: SingleChildScrollView(
                child: Container(
                  padding: EdgeInsets.fromLTRB(0, 10, 0, 0),
                  child: Text(
                    post.effectiveContent,
                    overflow: TextOverflow.fade,
                    style: TextStyle(color: Colors.black, fontSize: 19),
                  ),
                ),
              ),
            ),
            Row(
              mainAxisAlignment: MainAxisAlignment.end,
              children: [
                Text(
                  post.title != "" ? "${post.comments} Comments" : "",
                  textAlign: TextAlign.right,
                  style: TextStyle(fontSize: 16),
                ),
              ],
            )
          ],
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
        ),
      ),
    );
  }

  void redirectToUserGraph(BuildContext context) {
    // pop dialog
    Navigator.of(context).pop();
    Navigator.push(
        context,
        MaterialPageRoute(
          builder: (context) => UserGraphViewPage(post.author),
        ));
  }

  void redirectToCommunityGraph(BuildContext context) {
    // pop dialog
    Navigator.of(context).pop();
    Navigator.push(
      context,
      MaterialPageRoute(
        builder: (context) => CommunityGraphViewPage(post.community),
      ),
    );
  }
}
