import 'package:dashboard/data/community.dart';
import 'package:dashboard/data/post.dart';
import 'package:dashboard/querying/datagetter.dart';
import 'package:dashboard/util/loginhelper.dart';
import 'package:dashboard/util/user.dart';
import 'package:logger/logger.dart';

class ClusterGetter {
  Map<String, List<Community>> clusterMap;
  Future<List<Community>> getNodesfromLayer(String layerName) async {
    String url =
        "https://articonf1.itec.aau.at:30101/api/use-cases/reddit/tables/reddit/layers/$layerName/nodes";

    BackendUser user = await LoginHelper().loggedInUser;
    String token = user.token;

    Map<String, dynamic> headers = {"Authorization": "Bearer $token"};

    List<dynamic> nodesList =
        await DataGetter.getJsonList(url, headers: headers);
    
    Map<String, List<Post>> resultMap = {};
    List<Community> communityList = [];

    for (Map<String, dynamic> entry in nodesList) {
      bool communityExists = false;
      Community community;
      for (Community tmpCommunity in communityList) {
        if (tmpCommunity.name == entry["subreddit"]) {
          community = tmpCommunity;
          communityExists = true;
          break;
        }
      }

      if (!communityExists) {
        community = Community(entry["subreddit"], 1, []);
        communityList.add(community);
      }

      community.posts.add(Post(
          entry["title"],
          entry["content"],
          entry["user_id"],
          entry["subreddit"],
          entry["percentage_upvoted"],
          entry["n_comments"]));
    }

    return communityList;
  }

  Future<Map<String, List<Community>>> getClustersFuture() async {
    List<String> layers = [
      "Upvotes_Layer",
      "Percentage_Layer",
      "Engagement_Layer",
      "Time_Layer",
    ];

    Map<String, List<Community>> clusterMap = {};
    for (String layer in layers) {
      clusterMap[layer] = await getNodesfromLayer(layer);
    }
    Logger().i(clusterMap.toString());
    return clusterMap;
  }
}
