import 'dart:math';

import 'package:circlegraph/circlegraph.dart';
import 'package:dashboard/graphing/trustcolorcalculator.dart';
import 'package:dashboard/ui/graphs/community/circle/node_community.dart';
import 'package:dashboard/ui/theme/color_holder.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import '../../../../data/community.dart';
import '../../../../data/communityGraphNodeData.dart';
import '../../../../data/post.dart';
import '../../../../graphing/postnode.dart';

class CommunityGraph extends StatefulWidget {
  CommunityGraph(this.community, {this.offset = 0});
  final Community community;

  static const int postsPerPage = 21;
  final int offset;

  final double padding = 32;
  final double postWidth = 200;
  final double postHeight = 50;

  _CommunityGraphState createState() => _CommunityGraphState(community);
}

class _CommunityGraphState extends State<CommunityGraph> {
  _CommunityGraphState(this.community);
  final Community community;

  build(BuildContext context) {
    var nodes = [];

    int startPostIndex = widget.offset;
    int endPostIndex = min(
        startPostIndex + CommunityGraph.postsPerPage, community.posts.length);

    for (int i = startPostIndex; i < endPostIndex; i++) {
      nodes.add(community.posts[i]);
    }

    nodes.add(
      Post("...", "", "", community.name, community.trust, 70),
    );

    return Container(
      constraints: BoxConstraints.expand(),
      color: ColorHolder.color3,
      child: SingleChildScrollView(
        child: CircleGraph(
          backgroundColor: ColorHolder.color3,
          root: _getCommunityNode(community),
          children: [for (var node in nodes) _getPostNode(node)],
          edgeColor: Color.fromRGBO(212, 228, 188, 1),
          padding: EdgeInsets.zero,
          circleLayout: [
            Circle(10, 4),
            Circle(100, 8),
            Circle(220, -1),
          ],
        ),
      ),
    );
  }

  TreeNodeData<CommunityGraphNodeData> _getCommunityNode(Community community) {
    CommunityGraphNodeData data =
        CommunityGraphNodeData.fromCommunity(community);

    return TreeNodeData<CommunityGraphNodeData>(
      child: TrustScoreNode(
        community.name,
        community.trust,
        textColor: ColorHolder.color2,
        icon: Icons.group_work,
      ),
      data: data,
      width: 150,
      backgroundColor: ColorHolder.color1,
    );
  }

  TreeNodeData<CommunityGraphNodeData> _getPostNode(Post post) {
    CommunityGraphNodeData data = CommunityGraphNodeData.fromPost(post);
    PostNode postNode = PostNode(post);

    return TreeNodeData<CommunityGraphNodeData>(
      // child: postNode,
      child: TrustScoreNode(
        post.effectiveTitle,
        post.trust,
        textColor: ColorHolder.color2,
        icon: Icons.sticky_note_2,
      ),
      data: data,
      width: 200,
      backgroundColor: ColorHolder.color1,
      onNodeClick: _redirectToPost,
    );
  }

  void _redirectToPost(TreeNodeData node, CommunityGraphNodeData data) {
    showDialog(
        context: context,
        builder: (_) => new PostNodeDialog(data.getData(),
            TrustColorCalculator.calculateTrustColor(data.getData().trust)));
  }
}
