import 'package:dashboard/data/community.dart';
import 'package:dashboard/data/post.dart';
import 'package:dashboard/ui/theme/color_holder.dart';
import 'package:flutter/material.dart';

class CommunityCloud extends StatefulWidget {
  @override
  _CommunityCloudState createState() => _CommunityCloudState();

  final double padding = 32;
  final double postWidth = 200;
  final double postHeight = 50;

  final int offset;
  final Community community;

  CommunityCloud(this.community, this.offset);
}

class _CommunityCloudState extends State<CommunityCloud> {
  int _nextPostId;

  Widget _rowBuilder(int n) {
    List<Widget> children = [];

    for (int i = 0; i < n; i++) {
      int postNumber = _nextPostId++;

      Post post = widget.community.posts[postNumber];

      children.add(
        Container(
          width: widget.postWidth,
          height: widget.postHeight,
          padding: EdgeInsets.all(4),
          decoration: BoxDecoration(
            color: Colors.blue,
            borderRadius: BorderRadius.all(Radius.circular(10)),
          ),
          child: Row(
            children: [
              Icon(
                Icons.sticky_note_2,
                color: ColorHolder.color2,
              ),
              SizedBox(width: 4),
              Expanded(
                child: Text(
                  post.effectiveTitle,
                  overflow: TextOverflow.ellipsis,
                  maxLines: 2,
                  style: TextStyle(color: ColorHolder.color2),
                ),
              ),
              SizedBox(width: 4),
              Column(
                mainAxisAlignment: MainAxisAlignment.center,
                mainAxisSize: MainAxisSize.min,
                children: [
                  Icon(
                    post.trust > .5
                        ? Icons.thumb_up_sharp
                        : Icons.thumb_down_sharp,
                    color: ColorHolder.color2,
                    size: 15,
                  ),
                  Text(
                    post.formattedTrustScore,
                    style: TextStyle(color: ColorHolder.color2),
                  ),
                ],
              ),
            ],
          ),
        ),
      );
    }

    return Padding(
      padding: EdgeInsets.only(bottom: widget.padding),
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceEvenly,
        children: children,
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    _nextPostId = widget.offset;

    return Container(
      color: ColorHolder.color3,
      constraints: BoxConstraints.expand(),
      child: LayoutBuilder(
        builder: (BuildContext context, BoxConstraints constraints) {
          int postsPerRow =
              constraints.maxWidth ~/ (widget.postWidth + widget.padding);

          int nrows =
              constraints.maxHeight ~/ (widget.postHeight + widget.padding);

          return Padding(
            padding: EdgeInsets.only(top: widget.padding),
            child: Column(
              children: [
                for (int i = 0; i < nrows; i++)
                  _rowBuilder(postsPerRow - (i % 2)),
              ],
            ),
          );
        },
      ),
    );
  }
}
