import 'dart:math';

import 'package:dashboard/data/community.dart';
import 'package:dashboard/loading.dart';
import 'package:dashboard/querying/datagetter.dart';
import 'package:dashboard/ui/graphs/community/circle/communitygraph.dart';
import 'package:dashboard/ui/graphs/community/list/community_list.dart';
import 'package:dashboard/ui/graphs/community_meta/index.dart';
import 'package:flutter/material.dart';

class CommunityGraphViewPage extends StatefulWidget {
  final String communityname;

  CommunityGraphViewPage(this.communityname);

  @override
  _CommunityGraphViewPageState createState() => _CommunityGraphViewPageState();
}

class _CommunityGraphViewPageState extends State<CommunityGraphViewPage> {
  int _startIndex = 0;
  int _endIndex = 0;
  Community _data;

  bool _inCloudMode = true;

  void initState() {
    super.initState();
    _fetchData();
  }

  void _fetchData() async {
    _data = await DataGetter.getCommunity(widget.communityname);

    Navigator.of(context).pushReplacement(
      MaterialPageRoute(
        builder: (context) => CommunityList(_data, 0),
      ),
    );
  }

  void _onNext() {
    if (_data != null)
      setState(() {
        _endIndex = min(
          _endIndex + CommunityGraph.postsPerPage,
          _data.posts.length - 1,
        );
        _startIndex = max(
          0,
          _endIndex - CommunityGraph.postsPerPage,
        );
      });
  }

  void _onPrevious() {
    setState(() {
      _startIndex = max(0, _startIndex - CommunityGraph.postsPerPage);
      _endIndex = _startIndex + CommunityGraph.postsPerPage;
    });
  }

  void _toggleCloudMode(BuildContext context) {
    setState(() {
      _inCloudMode = !_inCloudMode;
    });
  }

  Widget build(BuildContext context) {
    return LoadingScreen(message: "Fetching posts...");
  }

  void redirectToCommunityMetaGraph(BuildContext context) {
    Navigator.push(
        context,
        MaterialPageRoute(
          builder: (context) => CommunityMetaGraphViewPage(),
        ));
  }
}
