import 'dart:html';
import 'dart:math';

import 'package:dashboard/data/community.dart';
import 'package:dashboard/ui/graphs/community/list/post_view.dart';
import 'package:dashboard/ui/theme/color_holder.dart';
import 'package:dashboard/ui/util/left_to_right_transition%20copy.dart';
import 'package:dashboard/ui/util/logged_in_appbar.dart';
import 'package:dashboard/ui/util/right_to_left_transition.dart';
import 'package:dashboard/ui/util/scrolldetector.dart';
import 'package:flutter/material.dart';

class CommunityList extends StatefulWidget {
  @override
  _CommunityListState createState() => _CommunityListState();

  final int offset;
  final Community community;

  final int nodesPerPage = 3;

  CommunityList(this.community, this.offset);
}

class _CommunityListState extends State<CommunityList> {
  void _previous() {
    int nextOffset = max(
      0,
      widget.offset - widget.nodesPerPage,
    );

    if (nextOffset != widget.offset)
      Navigator.of(context).pushReplacement(
        LeftToRightTransition(
          widget: CommunityList(
            widget.community,
            nextOffset,
          ),
        ),
      );
  }

  void _next() {
    int nextOffset = min(
      widget.community.posts.length - widget.nodesPerPage,
      widget.offset + widget.nodesPerPage,
    );

    if (nextOffset != widget.offset)
      Navigator.of(context).pushReplacement(
        RightToLeftTransition(
          widget: CommunityList(
            widget.community,
            nextOffset,
          ),
        ),
      );
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: LoggedInAppBar("Community: ${widget.community.name}"),
      body: ScrollDetector(
        onPointerScroll: (event) =>
            event.scrollDelta.dy < 0 ? _previous() : _next(),
        child: Stack(
          children: [
            Center(
              child: Container(
                constraints: BoxConstraints.expand(),
                color: ColorHolder.color3,
                child: Stack(
                  children: [
                    Align(
                      alignment: Alignment.center,
                      child: Column(
                        mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                        crossAxisAlignment: CrossAxisAlignment.end,
                        children: [
                          for (int i = widget.offset;
                              i <
                                  min(widget.community.posts.length,
                                      widget.offset + widget.nodesPerPage);
                              i++)
                            PostView(
                              widget.community.posts[i],
                              index: i + 1,
                              withExplanation: i == widget.offset,
                            ),
                        ],
                      ),
                    ),
                  ],
                ),
              ),
            )
          ],
        ),
      ),
    );
  }
}
