import 'package:dashboard/data/post.dart';
import 'package:dashboard/graphing/postnode.dart';
import 'package:flutter/material.dart';

class PostView extends StatelessWidget {
  final Post post;
  final int index;

  final bool withExplanation;

  PostView(
    this.post, {
    this.index = -1,
    this.withExplanation = false,
  });

  void _onPostTap(BuildContext context) {
    showDialog(
      context: context,
      builder: (context) => PostNodeDialog(
        post,
        Colors.green,
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    return Row(
      mainAxisSize: MainAxisSize.min,
      children: [
        if (withExplanation)
          SizedBox(
            width: 220,
            child: Column(
              mainAxisSize: MainAxisSize.min,
              crossAxisAlignment: CrossAxisAlignment.center,
              children: [
                Text(
                  "User post from the community ${post.community}",
                  style: TextStyle(
                    color: Colors.white,
                    fontSize: 20,
                  ),
                  textAlign: TextAlign.center,
                ),
                Image.asset(
                  "assets/drawn/line1.png",
                  width: 200,
                ),
              ],
            ),
          ),

        if (withExplanation)
          Image.asset(
            "assets/drawn/arrow.png",
            width: 200,
          ),

        // post content
        Container(
          width: 600,
          height: 200,
          alignment: Alignment.center,
          decoration: BoxDecoration(
            image: withExplanation
                ? DecorationImage(
                    image: AssetImage(
                      "assets/drawn/circle.png",
                    ),
                    fit: BoxFit.fill,
                  )
                : null,
          ),
          child: Stack(
            children: [
              Align(
                alignment: Alignment.center,
                child: GestureDetector(
                  onTap: () => _onPostTap(context),
                  child: Container(
                    width: 400,
                    child: Card(
                      child: Padding(
                        padding: const EdgeInsets.all(8.0),
                        child: Column(
                          mainAxisSize: MainAxisSize.min,
                          children: [
                            Text(
                              post.effectiveTitle,
                              style: TextStyle(
                                fontSize: 22,
                                fontWeight: FontWeight.bold,
                              ),
                              textAlign: TextAlign.center,
                            ),

                            // author credit
                            Row(
                              children: [
                                if (index > 0)
                                  Text(
                                    "#$index",
                                    style: TextStyle(
                                      fontStyle: FontStyle.italic,
                                    ),
                                  ),
                                Expanded(
                                  child: SizedBox(),
                                ),
                                Text(
                                  "by ${post.author}",
                                  style: TextStyle(
                                    fontStyle: FontStyle.italic,
                                  ),
                                ),
                              ],
                            ),
                          ],
                        ),
                      ),
                    ),
                  ),
                ),
              ),
            ],
          ),
        ),
      ],
    );
  }
}
