import 'dart:math';

import 'package:circlegraph/bubble/bubblegraph.dart';
import 'package:circlegraph/circlegraph.dart';
import 'package:dashboard/data/community.dart';
import 'package:dashboard/graphing/trustcolorcalculator.dart';
import 'package:dashboard/loading.dart';
import 'package:dashboard/querying/cluster.dart';
import 'package:dashboard/querying/datagetter.dart';
import 'package:dashboard/ui/graphs/community/index.dart';
import 'package:dashboard/ui/theme/color_holder.dart';
import 'package:dashboard/ui/util/logged_in_appbar.dart';
import 'package:flutter/material.dart';
import 'package:enhanced_future_builder/enhanced_future_builder.dart';

class CommunityMetaGraph extends StatefulWidget {
  final List<Community> communities;
  CommunityMetaGraph(this.communities);

  _CommunityMetaGraphState createState() =>
      _CommunityMetaGraphState(this.communities);
}

class _CommunityMetaGraphState extends State<CommunityMetaGraph> {
  final List<Community> communities;
  int postNodeCount = 10; // Nr of postNodes displayed
  _CommunityMetaGraphState(this.communities);

  Widget build(BuildContext context) {
    return SingleChildScrollView(
      child: BubbleGraph(
        communities
            .map(
              (Community community) => CircleGraph(
                root: TreeNodeData(
                  onNodeClick: (node, data) => Navigator.push(
                    context,
                    MaterialPageRoute(
                      builder: (context) => CommunityGraphViewPage(data.name),
                    ),
                  ),
                  data: community,
                  backgroundColor: ColorHolder.color1,
                  child: Container(
                    constraints: BoxConstraints.expand(),
                    child: Stack(
                      children: [
                        Align(
                          alignment: Alignment.topRight,
                          child: Container(
                            width: 70,
                            height: 70,
                            alignment: Alignment.center,
                            decoration: BoxDecoration(
                              shape: BoxShape.circle,
                              color: Colors.blue,
                            ),
                            child: Text(
                              community.formattedTrustScore,
                              style: TextStyle(
                                fontWeight: FontWeight.bold,
                                color: Colors.green[800],
                                fontSize: 14,
                              ),
                            ),
                          ),
                        ),
                        Align(
                          alignment: Alignment.center,
                          child: Padding(
                            padding: const EdgeInsets.only(top: 32.0),
                            child: Row(
                              mainAxisSize: MainAxisSize.min,
                              children: [
                                Icon(
                                  Icons.group_work,
                                  color: ColorHolder.color2,
                                ),
                                Text(
                                  "${community.name}",
                                  style: TextStyle(
                                    color: ColorHolder.color2,
                                  ),
                                ),
                              ],
                            ),
                          ),
                        ),
                      ],
                    ),
                  ),
                  height: 160,
                  width: 160,
                ),
                circlify: true,
                backgroundColor: ColorHolder.color1,
              ),
            )
            .toList(),
      ),
    );

    // return SingleChildScrollView(
    //   child: Wrap(
    //     children: [
    //       for (Community community in communities)
    //         getCommunityNodeWidget(community)
    //     ],
    //   ),
    // );
  }

  Widget getCommunityNodeWidget(Community community) {
    return GestureDetector(
        onTap: () => Navigator.push(
            context,
            MaterialPageRoute(
              builder: (context) => CommunityGraphViewPage(community.name),
            )),
        child: Container(
          width: 250,
          height: 50,
          decoration:
              BoxDecoration(color: Colors.blue, shape: BoxShape.rectangle),
          margin: EdgeInsets.all(7),
          padding: EdgeInsets.all(5),
          child: Row(
            children: [
              Expanded(
                child: Text(
                  community.name,
                  overflow: TextOverflow.ellipsis,
                  style: TextStyle(
                      fontWeight: FontWeight.bold, color: Colors.black),
                ),
              ),
              Text(
                (community.trust * 100 - Random().nextInt(20))
                        .roundToDouble()
                        .toString() +
                    "%",
                style: TextStyle(
                    fontWeight: FontWeight.bold,
                    color: TrustColorCalculator.calculateTrustColor(
                        community.trust)),
              ),
            ],
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
          ),
        ));
  }
}

class CommunityMetaGraphViewPage extends StatelessWidget {
  Widget build(BuildContext context) {
    ClusterGetter().getNodesfromLayer("Upvotes_Layer");
    return Scaffold(
      appBar: LoggedInAppBar("Communities"),
      backgroundColor: ColorHolder.color3,
      body: Container(
        padding: EdgeInsets.all(12),
        constraints: BoxConstraints.expand(),
        child: EnhancedFutureBuilder(
          future: DataGetter.getCommunities(),
          rememberFutureResult: false,
          whenDone: (communities) => CommunityMetaGraph(communities),
          whenNotDone: Container(
            alignment: Alignment.center,
            child: LoadingScreen(
              message: "Fetching Data...",
            ),
          ),
        ),
      ),
    );
  }
}
